@@ -7,6 +7,8 @@ from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 
 @Function
 def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, logMessage=DEFAULT_LOG_MESSAGE, status=HttpStatus.INTERNAL_SERVER_ERROR) :
+    encapsulateItWithGlobalExceptionMessage = message
+    encapsulateItWithGlobalExceptionLogMessage = logMessage
     encapsulateItWithGlobalExceptionStatus = status
     def wrapper(givenFunction,*args,**kwargs) :
         log.wrapper(wrapper, f'Wrapping {givenFunction} function with (*{args} args and **{kwargs} kwargs)')
@@ -16,7 +18,8 @@ def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, logMessage=DEFAULT
             except Exception as exception :
                 if isinstance(exception, GlobalException):
                     raise exception
-                logMessage = str(exception) if StringHelper.isNotBlank(str(exception)) else logMessage
+                message = encapsulateItWithGlobalExceptionMessage
+                logMessage = str(exception) if StringHelper.isNotBlank(str(exception)) else encapsulateItWithGlobalExceptionLogMessage
                 givenFunctionName = ReflectionHelper.getName(givenFunction, typeName=c.TYPE_FUNCTION)
                 log.wrapper(EncapsulateItWithGlobalException, f'''Failed to execute "{givenFunctionName}(args={args}, kwargs={kwargs})" {c.TYPE_FUNCTION} call''', exception)
                 raise GlobalException(
